@@ -50,6 +50,10 @@ class VendorCatalogHandler(BatchHandler):
         'ProductCost',
     ]
 
+    # can set these to e.g. Decimal('0.01') to "ignore" cost diffs below that
+    case_cost_diff_threshold = None
+    unit_cost_diff_threshold = None
+
     def should_populate(self, batch):
         # all vendor catalogs must come from data file
         return True
@@ -77,6 +81,12 @@ class VendorCatalogHandler(BatchHandler):
     setup_refresh = setup
 
     def populate(self, batch, progress=None):
+        """
+        Default logic just invokes :meth:`populate_from_file()`.
+        """
+        return self.populate_from_file(batch, progress=progress)
+
+    def populate_from_file(self, batch, progress=None):
         """
         Pre-fill batch with row data from an input data file, leveraging a
         specific catalog parser.
@@ -115,6 +125,9 @@ class VendorCatalogHandler(BatchHandler):
         the vendor, if the catalog contains a change etc.  Note that the
         product lookup is done first by UPC and then by vendor item code.
         """
+        # clear this first in case it's set
+        row.status_text = None
+
         row.product = self.identify_product(row)
         if not row.product:
             row.status_code = row.STATUS_PRODUCT_NOT_FOUND
@@ -134,44 +147,72 @@ class VendorCatalogHandler(BatchHandler):
         row.cost = old_cost
         row.old_vendor_code = old_cost.code
         row.old_case_size = old_cost.case_size
+        row.old_case_cost = old_cost.case_cost
+        row.old_unit_cost = old_cost.unit_cost
 
         # only consider vendor match if product does in fact have a vendor
         # TODO: at least i assume that's a reasonable idea?
         if row.product.costs:
             row.is_preferred_vendor = row.product.costs[0].vendor is row.batch.vendor
 
+        self.refresh_cost_diffs(row)
+        self.set_status_per_diffs(row)
+
+    def refresh_cost_diffs(self, row):
+
         # old_case_cost
-        row.old_case_cost = old_cost.case_cost
         if row.case_cost is not None and row.old_case_cost is not None:
             row.case_cost_diff = row.case_cost - row.old_case_cost
 
         # old_unit_cost
-        row.old_unit_cost = old_cost.unit_cost
         if row.unit_cost is not None and row.old_unit_cost is not None:
             row.unit_cost_diff = row.unit_cost - row.old_unit_cost
             if row.old_unit_cost:
                 row.unit_cost_diff_percent = row.unit_cost_diff / row.old_unit_cost
+            else:
+                row.unit_cost_diff_percent = 1
+
+    def set_status_per_diffs(self, row):
 
-        # status
         if row.vendor_code != row.old_vendor_code:
             row.status_code = row.STATUS_CHANGE_VENDOR_ITEM_CODE
             row.status_text = "new vendor item code {} differs from old code {}".format(
                 repr(row.vendor_code), repr(row.old_vendor_code))
-        elif row.case_size != row.old_case_size:
+            return
+
+        if row.case_size != row.old_case_size:
             row.status_code = row.STATUS_CHANGE_CASE_SIZE
             row.status_text = "new case size {} differs from old case size {}".format(
                 repr(row.case_size), repr(row.old_case_size))
-        elif row.case_cost != row.old_case_cost:
-            row.status_code = row.STATUS_CHANGE_COST
-            row.status_text = "new case cost {} differs from old cost {}".format(
-                repr(row.case_cost), repr(row.old_case_cost))
-        elif row.unit_cost != row.old_unit_cost:
-            row.status_code = row.STATUS_CHANGE_COST
-            row.status_text = "new unit cost {} differs from old cost {}".format(
-                repr(row.unit_cost), repr(row.old_unit_cost))
-        else:
-            row.status_code = row.STATUS_NO_CHANGE
+            return
 
+        if row.case_cost != row.old_case_cost:
+            diff_meets_threshold = True
+            if self.case_cost_diff_threshold and self.case_cost_diff_threshold > abs(
+                    row.case_cost - row.old_case_cost):
+                diff_meets_threshold = False
+            if diff_meets_threshold:
+                row.status_code = row.STATUS_CHANGE_COST
+                row.status_text = "new case cost {} differs from old cost {}".format(
+                    repr(row.case_cost), repr(row.old_case_cost))
+                return
+
+        if row.unit_cost != row.old_unit_cost:
+            diff_meets_threshold = True
+            if (self.unit_cost_diff_threshold
+                and row.unit_cost is not None and row.old_unit_cost is not None
+                and self.unit_cost_diff_threshold > abs(
+                    row.unit_cost - row.old_unit_cost)):
+                diff_meets_threshold = False
+            if diff_meets_threshold:
+                row.status_code = row.STATUS_CHANGE_COST
+                row.status_text = "new unit cost {} differs from old cost {}".format(
+                    repr(row.unit_cost), repr(row.old_unit_cost))
+                return
+
+        row.status_code = row.STATUS_NO_CHANGE
+
+    # TODO: who uses this..?
     def cost_differs(self, row, cost):
         """
         Compare a batch row with a cost record to determine whether they match
