@@ -825,8 +825,19 @@ class ConfigProfile(object):
 
     .. todo::
        This clearly needs more documentation.
+
+    .. attribute:: config
+       Reference to the primary Rattail config object for the running app.
+
+    .. attribute:: key
+       String identifier unique to this profile, within the broader
+       config section.
     """
 
+    def __init__(self, config, key, **kwargs):
+        self.config = config
+        self.key = key
+
     @property
     def section(self):
         """
