@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -54,7 +54,7 @@ The following enumerations are provided:
    from the SIL specification.
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 
 BATCH_ACTION_ADD                = 'ADD'
@@ -497,4 +497,10 @@ EMPLOYEE_STATUS = {
 #     }
 
 
-TRAINWRECK_SYSTEM = {}
+TRAINWRECK_SYSTEM_COREPOS       = 'corepos'
+TRAINWRECK_SYSTEM_LOCSMS        = 'locsms'
+
+TRAINWRECK_SYSTEM = {
+    TRAINWRECK_SYSTEM_COREPOS   : "CORE-POS",
+    TRAINWRECK_SYSTEM_LOCSMS    : "LOC SMS",
+}
