@@ -549,10 +549,17 @@ class Importer(object):
         """
         Normalize a local (raw) object into a data dict.
         """
-        data = {}
-        for field in self.simple_fields:
-            if field in self.fields:
-                data[field] = getattr(obj, field)
+        fields = [f for f in self.simple_fields
+                  if f in self.fields]
+        # note, we normally should have a proper object here, but in
+        # some (e.g. dry-run) cases we may just have a dict; we should
+        # do the right thing if so
+        if isinstance(obj, dict):
+            data = dict([(field, obj[field])
+                         for field in fields])
+        else:
+            data = dict([(field, getattr(obj, field))
+                         for field in fields])
         return data
 
     def get_local_object(self, key):
