@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
@@ -27,6 +27,8 @@ Sample -> Rattail data import
 from __future__ import unicode_literals, absolute_import
 
 import os
+import datetime
+import decimal
 import logging
 
 from rattail import importing
@@ -125,6 +127,12 @@ class UserImporter(FromSample, importing.model.AdminUserImporter):
         data['admin'] = parse_bool(data['admin']) if data['admin'] else None
         return data
 
+    def data_diffs(self, local_data, host_data):
+        diffs = super(UserImporter, self).data_diffs(local_data, host_data)
+        if 'plain_password' in diffs:
+            diffs.remove('plain_password')
+        return diffs
+
 
 class StoreImporter(FromSample, importing.model.StoreImporter):
 
@@ -141,6 +149,11 @@ class EmployeeImporter(FromSample, importing.model.EmployeeImporter):
         data = dict(row)
         data['id'] = int(data['id']) if data['id'] else None
         data['status'] = int(data['status']) if data['status'] else None
+        data['full_time'] = parse_bool(data['full_time'])
+        if data['full_time_start']:
+            data['full_time_start'] = datetime.datetime.strptime(data['full_time_start'], '%Y-%m-%d').date()
+        else:
+            data['full_time_start'] = None
         return data
 
 
@@ -148,10 +161,22 @@ class EmployeeStoreImporter(FromSample, importing.model.EmployeeStoreImporter):
     pass
 
 class CustomerImporter(FromSample, importing.model.CustomerImporter):
-    pass
+
+    def normalize_host_object(self, row):
+        data = dict(row)
+        data['number'] = int(data['number']) if data['number'] else None
+        data['email_preference'] = int(data['email_preference']) if data['email_preference'] else None
+        data['active_in_pos'] = parse_bool(data['active_in_pos'])
+        data['active_in_pos_sticky'] = parse_bool(data['active_in_pos_sticky'])
+        return data
+
 
 class CustomerPersonImporter(FromSample, importing.model.CustomerPersonImporter):
-    pass
+
+    def normalize_host_object(self, row):
+        data = dict(row)
+        data['ordinal'] = int(data['ordinal']) if data['ordinal'] else None
+        return data
 
 
 class VendorImporter(FromSample, importing.model.VendorImporter):
@@ -164,13 +189,28 @@ class VendorImporter(FromSample, importing.model.VendorImporter):
 
 
 class VendorContactImporter(FromSample, importing.model.VendorContactImporter):
-    pass
+
+    def normalize_host_object(self, row):
+        data = dict(row)
+        data['preference'] = int(data['preference']) if data['preference'] else None
+        return data
+
 
 class DepartmentImporter(FromSample, importing.model.DepartmentImporter):
-    pass
+
+    def normalize_host_object(self, row):
+        data = dict(row)
+        data['number'] = int(data['number']) if data['number'] else None
+        return data
+
 
 class SubdepartmentImporter(FromSample, importing.model.SubdepartmentImporter):
-    pass
+
+    def normalize_host_object(self, row):
+        data = dict(row)
+        data['number'] = int(data['number']) if data['number'] else None
+        return data
+
 
 class BrandImporter(FromSample, importing.model.BrandImporter):
     pass
@@ -202,6 +242,14 @@ class ProductCostImporter(FromSample, importing.model.ProductCostImporter):
         'unit_cost',
     ]
 
+    def normalize_host_object(self, row):
+        data = dict(row)
+        data['preference'] = int(data['preference']) if data['preference'] else None
+        data['case_size'] = decimal.Decimal(data['case_size']) if data['case_size'] else None
+        data['case_cost'] = decimal.Decimal(data['case_cost']) if data['case_cost'] else None
+        data['unit_cost'] = decimal.Decimal(data['unit_cost']) if data['unit_cost'] else None
+        return data
+
 
 # class ProductPriceImporter(FromSample, importing.model.ProductPriceImporter):
 #     pass
