@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,6 +32,7 @@ import six
 import lockfile
 
 from rattail.config import get_user_file
+from rattail.batch import batch_id_str
 
 
 def consume_batch_id(source='RATAIL'):
@@ -59,4 +60,4 @@ def consume_batch_id(source='RATAIL'):
         with open(path, 'wt') as f:
             parser.write(f)
 
-    return '{0:08d}'.format(batch_id)
+    return batch_id_str(batch_id)
