@@ -22,10 +22,6 @@ class SAErrorHelper(object):
 
 class TestCustomerPerson(DataTestCase, SAErrorHelper):
 
-    def test_repr(self):
-        assoc = model.CustomerPerson(uuid='whatever')
-        self.assertEqual(repr(assoc), "CustomerPerson(uuid=u'whatever')")
-
     def test_customer_required(self):
         assoc = model.CustomerPerson(person=model.Person())
         self.session.add(assoc)
@@ -63,10 +59,6 @@ class TestCustomerPerson(DataTestCase, SAErrorHelper):
 
 class TestCustomerGroupAssignment(DataTestCase, SAErrorHelper):
 
-    def test_repr(self):
-        assignment = model.CustomerGroupAssignment(uuid='whatever')
-        self.assertEqual(repr(assignment), "CustomerGroupAssignment(uuid=u'whatever')")
-
     def test_customer_required(self):
         assignment = model.CustomerGroupAssignment(group=model.CustomerGroup())
         self.session.add(assignment)
